Method: Vedeu::ApplicationView#render

Defined in:
lib/vedeu/application/application_view.rb

#renderObject

Note:

Client applications should implement this method.

Raises:

  • (Vedeu::Error::NotImplemented)

    When the method called should be handled by a subclass of the current class, or by the class including or extending the current module.



38
39
40
# File 'lib/vedeu/application/application_view.rb', line 38

def render
  raise Vedeu::Error::NotImplemented
end