Method: Vedeu::Interfaces::Interface#deputy

Defined in:
lib/vedeu/interfaces/interface.rb

#deputy(client = nil) ⇒ Vedeu::Interfaces::DSL

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a DSL instance responsible for defining the DSL methods of this model.

Parameters:

  • client (Object|NilClass) (defaults to: nil)

    The client binding represents the client application object that is currently invoking a DSL method. It is required so that we can send messages to the client application object should we need to.

Returns:



109
110
111
# File 'lib/vedeu/interfaces/interface.rb', line 109

def deputy(client = nil)
  Vedeu::Interfaces::DSL.new(self, client)
end