Method: Vedeu::Interfaces::Interface#hide

Defined in:
lib/vedeu/interfaces/interface.rb

#hidevoid

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

This method returns an undefined value.

Hide the named interface.

Will hide the named interface. If the interface is currently visible, it will be cleared- rendered blank. To show the interface, the ‘:show_interface’ event should be triggered. Triggering the ‘:hide_group’ event to which this named interface belongs will also hide the interface.

Examples:

Vedeu.trigger(:_hide_interface_, name)
Vedeu.hide_interface(name)


126
127
128
129
130
# File 'lib/vedeu/interfaces/interface.rb', line 126

def hide
  super

  Vedeu.trigger(:_clear_view_, name)
end