Method: Vedeu::Interfaces::Interface#show

Defined in:
lib/vedeu/interfaces/interface.rb

#showvoid

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

This method returns an undefined value.

Show the named interface.

Will show the named interface. If the interface is currently visible, it will be refreshed- showing any new content available. To hide the interface, the ‘:hide_interface’ event should be triggered. Triggering the ‘:show_group’ event to which this named interface belongs will also show the interface.

Examples:

Vedeu.trigger(:_show_interface_, name)
Vedeu.show_interface(name)


146
147
148
149
150
# File 'lib/vedeu/interfaces/interface.rb', line 146

def show
  super

  Vedeu.trigger(:_refresh_view_, name)
end