Method: Vedeu::Borders::Border#name

Defined in:
lib/vedeu/borders/border.rb

#nameNilClass|Symbol|String (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns The name of the model, the target model or the name of the associated model.

Returns:

  • (NilClass|Symbol|String)

    The name of the model, the target model or the name of the associated model.



116
117
118
# File 'lib/vedeu/borders/border.rb', line 116

def name
  @name
end