Method: Vedeu::Interfaces::DSL.add_keymap!

Defined in:
lib/vedeu/interfaces/dsl.rb

.add_keymap!(name) ⇒ NilClass|Vedeu::Input::Keymap (private)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Registers a new keymap for the interface unless already registered.

Parameters:

  • name (NilClass|Symbol|String)

    The name of the model or target model to act upon. May default to Vedeu.focus.

Returns:



102
103
104
# File 'lib/vedeu/interfaces/dsl.rb', line 102

def add_keymap!(name)
  Vedeu::Input::Keymap.store(name: name) unless keymap?(name)
end