Module: Vedeu

Extended by:
Forwardable, Vedeu
Included in:
Vedeu
Defined in:
lib/vedeu.rb,
lib/vedeu/error.rb,
lib/vedeu/common.rb,
lib/vedeu/boolean.rb,
lib/vedeu/dsl/all.rb,
lib/vedeu/dsl/dsl.rb,
lib/vedeu/dsl/use.rb,
lib/vedeu/esc/all.rb,
lib/vedeu/esc/esc.rb,
lib/vedeu/version.rb,
lib/vedeu/dsl/view.rb,
lib/vedeu/null/all.rb,
lib/vedeu/sentence.rb,
lib/vedeu/cells/all.rb,
lib/vedeu/dsl/views.rb,
lib/vedeu/esc/mouse.rb,
lib/vedeu/input/all.rb,
lib/vedeu/input/dsl.rb,
lib/vedeu/input/key.rb,
lib/vedeu/input/raw.rb,
lib/vedeu/menus/all.rb,
lib/vedeu/menus/dsl.rb,
lib/vedeu/views/all.rb,
lib/vedeu/cells/char.rb,
lib/vedeu/dsl/border.rb,
lib/vedeu/editor/all.rb,
lib/vedeu/events/all.rb,
lib/vedeu/groups/all.rb,
lib/vedeu/groups/dsl.rb,
lib/vedeu/input/keys.rb,
lib/vedeu/input/read.rb,
lib/vedeu/menus/menu.rb,
lib/vedeu/models/all.rb,
lib/vedeu/models/row.rb,
lib/vedeu/output/all.rb,
lib/vedeu/views/line.rb,
lib/vedeu/views/view.rb,
lib/vedeu/borders/all.rb,
lib/vedeu/borders/dsl.rb,
lib/vedeu/buffers/all.rb,
lib/vedeu/cells/clear.rb,
lib/vedeu/cells/empty.rb,
lib/vedeu/colours/all.rb,
lib/vedeu/cursors/all.rb,
lib/vedeu/cursors/dsl.rb,
lib/vedeu/dsl/cursors.rb,
lib/vedeu/editor/item.rb,
lib/vedeu/editor/line.rb,
lib/vedeu/esc/actions.rb,
lib/vedeu/esc/borders.rb,
lib/vedeu/esc/colours.rb,
lib/vedeu/input/mouse.rb,
lib/vedeu/input/store.rb,
lib/vedeu/logging/all.rb,
lib/vedeu/logging/log.rb,
lib/vedeu/models/page.rb,
lib/vedeu/runtime/all.rb,
lib/vedeu/views/chars.rb,
lib/vedeu/views/lines.rb,
lib/vedeu/views/value.rb,
lib/vedeu/views/views.rb,
lib/vedeu/buffers/null.rb,
lib/vedeu/buffers/view.rb,
lib/vedeu/cells/border.rb,
lib/vedeu/cells/cursor.rb,
lib/vedeu/cells/escape.rb,
lib/vedeu/coercers/all.rb,
lib/vedeu/coercers/row.rb,
lib/vedeu/cursors/move.rb,
lib/vedeu/dsl/elements.rb,
lib/vedeu/dsl/geometry.rb,
lib/vedeu/editor/lines.rb,
lib/vedeu/events/event.rb,
lib/vedeu/groups/clear.rb,
lib/vedeu/groups/group.rb,
lib/vedeu/input/keymap.rb,
lib/vedeu/input/mapper.rb,
lib/vedeu/models/focus.rb,
lib/vedeu/null/generic.rb,
lib/vedeu/output/write.rb,
lib/vedeu/terminal/all.rb,
lib/vedeu/views/stream.rb,
lib/vedeu/borders/title.rb,
lib/vedeu/buffers/clear.rb,
lib/vedeu/buffers/empty.rb,
lib/vedeu/coercers/page.rb,
lib/vedeu/editor/cursor.rb,
lib/vedeu/editor/delete.rb,
lib/vedeu/editor/editor.rb,
lib/vedeu/editor/insert.rb,
lib/vedeu/events/events.rb,
lib/vedeu/input/capture.rb,
lib/vedeu/logging/debug.rb,
lib/vedeu/logging/timer.rb,
lib/vedeu/output/output.rb,
lib/vedeu/renderers/all.rb,
lib/vedeu/runtime/flags.rb,
lib/vedeu/runtime/traps.rb,
lib/vedeu/support/point.rb,
lib/vedeu/terminal/mode.rb,
lib/vedeu/views/streams.rb,
lib/vedeu/borders/border.rb,
lib/vedeu/buffers/buffer.rb,
lib/vedeu/coercers/chars.rb,
lib/vedeu/coercers/lines.rb,
lib/vedeu/coercers/style.rb,
lib/vedeu/colours/colour.rb,
lib/vedeu/cursors/cursor.rb,
lib/vedeu/editor/cropper.rb,
lib/vedeu/esc/background.rb,
lib/vedeu/esc/foreground.rb,
lib/vedeu/events/aliases.rb,
lib/vedeu/events/trigger.rb,
lib/vedeu/geometries/all.rb,
lib/vedeu/groups/refresh.rb,
lib/vedeu/interfaces/all.rb,
lib/vedeu/interfaces/dsl.rb,
lib/vedeu/output/refresh.rb,
lib/vedeu/plugins/plugin.rb,
lib/vedeu/renderers/html.rb,
lib/vedeu/renderers/json.rb,
lib/vedeu/renderers/text.rb,
lib/vedeu/runtime/router.rb,
lib/vedeu/templating/all.rb,
lib/vedeu/borders/caption.rb,
lib/vedeu/borders/refresh.rb,
lib/vedeu/buffers/refresh.rb,
lib/vedeu/coercers/colour.rb,
lib/vedeu/cursors/refresh.rb,
lib/vedeu/distributed/all.rb,
lib/vedeu/distributed/uri.rb,
lib/vedeu/dsl/helpers/all.rb,
lib/vedeu/editor/document.rb,
lib/vedeu/geometries/move.rb,
lib/vedeu/interfaces/null.rb,
lib/vedeu/output/viewport.rb,
lib/vedeu/plugins/plugins.rb,
lib/vedeu/application/view.rb,
lib/vedeu/buffers/terminal.rb,
lib/vedeu/coercers/coercer.rb,
lib/vedeu/coercers/streams.rb,
lib/vedeu/dsl/helpers/text.rb,
lib/vedeu/dsl/presentation.rb,
lib/vedeu/input/repository.rb,
lib/vedeu/input/translator.rb,
lib/vedeu/interfaces/clear.rb,
lib/vedeu/menus/repository.rb,
lib/vedeu/presentation/all.rb,
lib/vedeu/renderers/escape.rb,
lib/vedeu/repositories/all.rb,
lib/vedeu/runtime/launcher.rb,
lib/vedeu/cells/borders/all.rb,
lib/vedeu/coercers/position.rb,
lib/vedeu/colours/validator.rb,
lib/vedeu/configuration/all.rb,
lib/vedeu/configuration/api.rb,
lib/vedeu/dsl/helpers/align.rb,
lib/vedeu/editor/collection.rb,
lib/vedeu/editor/repository.rb,
lib/vedeu/events/repository.rb,
lib/vedeu/groups/repository.rb,
lib/vedeu/models/toggleable.rb,
lib/vedeu/output/compressor.rb,
lib/vedeu/runtime/bootstrap.rb,
lib/vedeu/runtime/main_loop.rb,
lib/vedeu/terminal/terminal.rb,
lib/vedeu/views/composition.rb,
lib/vedeu/application/helper.rb,
lib/vedeu/borders/repository.rb,
lib/vedeu/buffers/repository.rb,
lib/vedeu/cells/support/html.rb,
lib/vedeu/coercers/alignment.rb,
lib/vedeu/colours/background.rb,
lib/vedeu/colours/foreground.rb,
lib/vedeu/colours/repository.rb,
lib/vedeu/colours/translator.rb,
lib/vedeu/cursors/coordinate.rb,
lib/vedeu/cursors/reposition.rb,
lib/vedeu/cursors/repository.rb,
lib/vedeu/distributed/client.rb,
lib/vedeu/distributed/server.rb,
lib/vedeu/geometries/dsl/all.rb,
lib/vedeu/geometries/dsl/dsl.rb,
lib/vedeu/logging/clock_time.rb,
lib/vedeu/presentation/style.rb,
lib/vedeu/renderers/terminal.rb,
lib/vedeu/repositories/cache.rb,
lib/vedeu/repositories/model.rb,
lib/vedeu/repositories/store.rb,
lib/vedeu/templating/decoder.rb,
lib/vedeu/templating/encoder.rb,
lib/vedeu/templating/helpers.rb,
lib/vedeu/colours/backgrounds.rb,
lib/vedeu/colours/foregrounds.rb,
lib/vedeu/geometries/area/all.rb,
lib/vedeu/geometries/dsl/grid.rb,
lib/vedeu/geometries/geometry.rb,
lib/vedeu/geometries/position.rb,
lib/vedeu/logging/mono_logger.rb,
lib/vedeu/presentation/colour.rb,
lib/vedeu/presentation/parent.rb,
lib/vedeu/presentation/styles.rb,
lib/vedeu/runtime/application.rb,
lib/vedeu/templating/template.rb,
lib/vedeu/cells/borders/corner.rb,
lib/vedeu/coercers/editor_line.rb,
lib/vedeu/dsl/helpers/truncate.rb,
lib/vedeu/dsl/helpers/wordwrap.rb,
lib/vedeu/geometries/area/area.rb,
lib/vedeu/interfaces/interface.rb,
lib/vedeu/repositories/storage.rb,
lib/vedeu/support/x_coordinate.rb,
lib/vedeu/support/y_coordinate.rb,
lib/vedeu/coercers/editor_lines.rb,
lib/vedeu/geometries/repository.rb,
lib/vedeu/interfaces/repository.rb,
lib/vedeu/presentation/position.rb,
lib/vedeu/repositories/defaults.rb,
lib/vedeu/application/controller.rb,
lib/vedeu/cells/borders/vertical.rb,
lib/vedeu/distributed/subprocess.rb,
lib/vedeu/dsl/helpers/attributes.rb,
lib/vedeu/output/compressors/all.rb,
lib/vedeu/renderers/support/file.rb,
lib/vedeu/buffers/refresh_content.rb,
lib/vedeu/output/compressor_cache.rb,
lib/vedeu/repositories/assemblage.rb,
lib/vedeu/repositories/collection.rb,
lib/vedeu/repositories/repository.rb,
lib/vedeu/cells/borders/horizontal.rb,
lib/vedeu/interfaces/clear_content.rb,
lib/vedeu/output/compressors/empty.rb,
lib/vedeu/templating/view_template.rb,
lib/vedeu/views/default_attributes.rb,
lib/vedeu/geometries/area/dimension.rb,
lib/vedeu/output/compressors/simple.rb,
lib/vedeu/presentation/presentation.rb,
lib/vedeu/renderers/support/options.rb,
lib/vedeu/repositories/registerable.rb,
lib/vedeu/repositories/repositories.rb,
lib/vedeu/coercers/colour_attributes.rb,
lib/vedeu/coercers/vertical_alignment.rb,
lib/vedeu/configuration/configuration.rb,
lib/vedeu/geometries/area/x_dimension.rb,
lib/vedeu/geometries/area/y_dimension.rb,
lib/vedeu/logging/lockless_log_device.rb,
lib/vedeu/application/application_view.rb,
lib/vedeu/output/compressors/character.rb,
lib/vedeu/coercers/horizontal_alignment.rb,
lib/vedeu/application/application_helper.rb,
lib/vedeu/cells/borders/vertices/top_left.rb,
lib/vedeu/cells/borders/vertices/top_right.rb,
lib/vedeu/cells/borders/edges/left_vertical.rb,
lib/vedeu/application/application_controller.rb,
lib/vedeu/cells/borders/edges/right_vertical.rb,
lib/vedeu/cells/borders/edges/top_horizontal.rb,
lib/vedeu/cells/borders/vertices/bottom_left.rb,
lib/vedeu/cells/borders/vertices/bottom_right.rb,
lib/vedeu/cells/borders/edges/bottom_horizontal.rb

Overview

frozen_string_literal: true

Defined Under Namespace

Modules: ApplicationHelper, Borders, Buffers, Cells, Coercers, Colours, Common, Config, Controller, Cursors, DSL, Distributed, Editor, Error, EscapeSequences, Events, Geometries, Groups, Helper, Input, Interfaces, Logging, Menus, Models, Null, Output, Presentation, Renderers, Repositories, Runtime, Templating, Terminal, Toggleable, View, Views Classes: ApplicationController, ApplicationView, Boolean, Configuration, Launcher, Plugin, Plugins, Point, Sentence, XCoordinate, YCoordinate

Constant Summary collapse

VERSION =

The current version of Vedeu.

'0.8.32'
ESCAPE_KEY_CODE =

Produces ASCII character 27 which is ESC

27
KEY_TABLE =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Maps keypress escape sequences to symbols for special keys.

{
  # "\u0020" => :ctrl_t, # duplicates spacebar
  # "\u0009" => :ctrl_i, # duplicates tab
  "\u0001" => :ctrl_a,
  "\u0002" => :ctrl_b,
  "\u0003" => :ctrl_c,
  "\u2404" => :ctrl_c,
  "\u0004" => :ctrl_d,
  "\u2403" => :ctrl_d,
  "\u0005" => :ctrl_e,
  "\u0006" => :ctrl_f,
  "\u0007" => :ctrl_g,
  "\u0008" => :ctrl_h,
  "\u0010" => :ctrl_j,
  "\u0011" => :ctrl_k,
  "\u0012" => :ctrl_l,
  "\u0013" => :ctrl_m,
  "\u0014" => :ctrl_n,
  "\u0015" => :ctrl_o,
  "\u0016" => :ctrl_p,
  "\u0017" => :ctrl_q,
  "\u0018" => :ctrl_r,
  "\u2412" => :ctrl_r,
  "\u0019" => :ctrl_s,
  %(\u0021) => :ctrl_u,
  %(\u0022) => :ctrl_v,
  %(\u0023) => :ctrl_w,
  %(\u0024) => :ctrl_x,
  %(\u0025) => :ctrl_y,
  %(\u0026) => :ctrl_z,
  "\eOP"   => :f1,
  "\eOQ"   => :f2,
  "\eOR"   => :f3,
  "\eOS"   => :f4,
  "\e[15~" => :f5,
  "\e[17~" => :f6,
  "\e[18~" => :f7,
  "\e[19~" => :f8,
  "\e[20~" => :f9,
  "\e[21~" => :f10,
  "\e[23~" => :f11,
  "\e[24~" => :f12,
  "\e[15;2~" => :shift_f5,
  "\e[17;2~" => :shift_f6,
  "\e[18;2~" => :shift_f7,
  "\e[19;2~" => :shift_f8,
  "\e[20;2~" => :shift_f9,
  "\e[21;2~" => :shift_f10,
  "\e[23;2~" => :shift_f11,
  "\e[24;2~" => :shift_f12,
  "\e[15;5~" => :ctrl_f5,
  "\e[17;5~" => :ctrl_f6,
  "\e[18;5~" => :ctrl_f7,
  "\e[19;5~" => :ctrl_f8,
  "\e[20;5~" => :ctrl_f9,
  "\e[21;5~" => :ctrl_f10,
  "\e[23;5~" => :ctrl_f11,
  "\e[24;5~" => :ctrl_f12,
  "\e[B"     => :down,
  "\u2193"   => :down,
  "\e[D"     => :left,
  "\u2190"   => :left,
  "\e[C"     => :right,
  "\u2192"   => :right,
  "\e[A"     => :up,
  "\u2191"   => :up,
  "\u007F"   => :backspace,
  "\u2408"   => :backspace,
  "\u23CE"   => :carriage_return,
  "\e[3~"    => :delete,
  "\u232B"   => :delete,
  "\e[F"     => :end,
  "\eOF"     => :end,
  "\r"       => :enter,
  "\n"       => :enter,
  "\e"       => :escape,
  "\u238B"   => :escape,
  "\e[H"     => :home,
  "\eOH"     => :home,
  "\e[2~"    => :insert,
  "\u240A"   => :line_feed,
  "\e[5~"    => :page_up,
  "\e[6~"    => :page_down,
  "\e[1;2R"  => :pause_break,
  "\e[1;2P"  => :print_screen,
  "\e[1;2Q"  => :scroll_lock,
  "\e[Z"     => :shift_tab,
  "\t"       => :tab,
  "\u21B9"   => :tab,
}.freeze
LOG_TYPES =

The defined message types for Vedeu with their respective colours. When used, produces a log entry of the format:

[type] message

The ‘type’ will be shown as the first colour defined in the value array, whilst the ‘message’ will be shown using the last colour.

{
  blue:     [:light_blue,    :blue],
  buffer:   [:light_green,   :green],
  compress: [:white,         :light_grey],
  config:   [:light_blue,    :blue],
  create:   [:light_cyan,    :cyan],
  cursor:   [:light_green,   :green],
  cyan:     [:light_cyan,    :cyan],
  debug:    [:white,         :light_grey],
  drb:      [:light_blue,    :blue],
  dsl:      [:light_blue,    :blue],
  editor:   [:light_blue,    :blue],
  error:    [:light_red,     :red],
  event:    [:light_magenta, :magenta],
  green:    [:light_green,   :green],
  info:     [:white,         :light_grey],
  input:    [:light_yellow,  :yellow],
  magenta:  [:light_magenta, :magenta],
  nonevent: [:magenta,       :light_magenta],
  output:   [:light_yellow,  :yellow],
  red:      [:light_red,     :red],
  render:   [:light_green,   :green],
  reset:    [:light_cyan,    :cyan],
  store:    [:light_cyan,    :cyan],
  test:     [:white,         :light_grey],
  timer:    [:light_blue,    :blue],
  update:   [:light_cyan,    :cyan],
  white:    [:white,         :light_grey],
  yellow:   [:light_yellow,  :yellow],
}.freeze
LOG_TYPES_KEYS =
Vedeu::LOG_TYPES.keys.freeze

Instance Method Summary collapse

Instance Method Details

#add_commandObject



84
85
86
87
88
89
90
# File 'lib/vedeu/input/store.rb', line 84

def_delegators Vedeu::Input::Store,
:add_command,
:add_keypress,
:all_commands,
:all_keypresses,
:last_command,
:last_keypress

#add_keypressObject



84
85
86
87
88
89
90
# File 'lib/vedeu/input/store.rb', line 84

def_delegators Vedeu::Input::Store,
:add_command,
:add_keypress,
:all_commands,
:all_keypresses,
:last_command,
:last_keypress

#all_commandsObject



84
85
86
87
88
89
90
# File 'lib/vedeu/input/store.rb', line 84

def_delegators Vedeu::Input::Store,
:add_command,
:add_keypress,
:all_commands,
:all_keypresses,
:last_command,
:last_keypress

#all_keypressesObject



84
85
86
87
88
89
90
# File 'lib/vedeu/input/store.rb', line 84

def_delegators Vedeu::Input::Store,
:add_command,
:add_keypress,
:all_commands,
:all_keypresses,
:last_command,
:last_keypress

#background_coloursVedeu::Colours::Backgrounds



27
28
# File 'lib/vedeu/colours/backgrounds.rb', line 27

def_delegators Vedeu::Colours::Backgrounds,
:background_colours

#bindObject



290
291
292
293
# File 'lib/vedeu/events/event.rb', line 290

def_delegators Vedeu::Events::Event,
:bind,
:bound?,
:unbind

#bind_aliasObject



94
95
96
# File 'lib/vedeu/events/aliases.rb', line 94

def_delegators Vedeu::Events::Aliases,
:bind_alias,
:unbind_alias

#borderObject



331
332
# File 'lib/vedeu/borders/dsl.rb', line 331

def_delegators Vedeu::Borders::DSL,
:border

#bordersVedeu::Borders::Repository



25
26
# File 'lib/vedeu/borders/repository.rb', line 25

def_delegators Vedeu::Borders::Repository,
:borders

#bound?Object



290
291
292
293
# File 'lib/vedeu/events/event.rb', line 290

def_delegators Vedeu::Events::Event,
:bind,
:bound?,
:unbind

#buffer_updateObject

See Also:



109
# File 'lib/vedeu/output/output.rb', line 109

def_delegators Vedeu::Output::Output, :buffer_update

#buffer_writeObject

See Also:



114
# File 'lib/vedeu/output/output.rb', line 114

def_delegators Vedeu::Output::Output, :buffer_write

#buffersVedeu::Buffers::Repository

Manipulate the repository of buffers.

Examples:

Vedeu.buffers


34
35
# File 'lib/vedeu/buffers/repository.rb', line 34

def_delegators Vedeu::Buffers::Repository,
:buffers

#centre_xObject



173
174
175
176
# File 'lib/vedeu/terminal/terminal.rb', line 173

def_delegators Vedeu::Terminal,
:centre_x,
:centre_y,
:resize

#centre_yObject



173
174
175
176
# File 'lib/vedeu/terminal/terminal.rb', line 173

def_delegators Vedeu::Terminal,
:centre_x,
:centre_y,
:resize

#clearObject



99
100
101
# File 'lib/vedeu/buffers/terminal.rb', line 99

def_delegators Vedeu::Buffers::Terminal,
:clear,
:refresh

#clear_by_groupObject



64
65
# File 'lib/vedeu/groups/clear.rb', line 64

def_delegators Vedeu::Groups::Clear,
:clear_by_group

#clear_by_nameObject



90
91
# File 'lib/vedeu/interfaces/clear.rb', line 90

def_delegators Vedeu::Interfaces::Clear,
:clear_by_name

#clear_content_by_nameObject

See Also:

  • Vedeu::Interfaces.ClearContent.clear_content_by_name


112
113
# File 'lib/vedeu/interfaces/clear_content.rb', line 112

def_delegators Vedeu::Interfaces::ClearContent,
:clear_content_by_name

#clock_timeObject



33
34
# File 'lib/vedeu/logging/clock_time.rb', line 33

def_delegators Vedeu::Logging::ClockTime,
:clock_time

#configObject



483
484
485
486
487
488
# File 'lib/vedeu/configuration/configuration.rb', line 483

def_delegators Vedeu::Configuration,
:config,
:configure,
:configuration,
:height,
:width

#configurationObject



483
484
485
486
487
488
# File 'lib/vedeu/configuration/configuration.rb', line 483

def_delegators Vedeu::Configuration,
:config,
:configure,
:configuration,
:height,
:width

#configureObject



483
484
485
486
487
488
# File 'lib/vedeu/configuration/configuration.rb', line 483

def_delegators Vedeu::Configuration,
:config,
:configure,
:configuration,
:height,
:width

#cursorObject



47
48
# File 'lib/vedeu/cursors/repository.rb', line 47

def_delegators Vedeu::Cursors::Repository,
:cursor

#cursorsVedeu::Cursors::Repository



40
41
# File 'lib/vedeu/cursors/repository.rb', line 40

def_delegators Vedeu::Cursors::Repository,
:cursors

#debugvoid

This method returns an undefined value.



130
131
# File 'lib/vedeu/logging/debug.rb', line 130

def_delegators Vedeu::Logging::Debug,
:debug

#direct_writeObject

See Also:



119
# File 'lib/vedeu/output/output.rb', line 119

def_delegators Vedeu::Output::Output, :direct_write

#documentsVedeu::Editor::Repository

Manipulate the repository of documents.

Examples:

Vedeu.documents


28
29
# File 'lib/vedeu/editor/repository.rb', line 28

def_delegators Vedeu::Editor::Repository,
:documents

#drb_restartObject



256
257
258
259
260
# File 'lib/vedeu/distributed/server.rb', line 256

def_delegators Vedeu::Distributed::Server,
:drb_restart,
:drb_start,
:drb_status,
:drb_stop

#drb_startObject



256
257
258
259
260
# File 'lib/vedeu/distributed/server.rb', line 256

def_delegators Vedeu::Distributed::Server,
:drb_restart,
:drb_start,
:drb_status,
:drb_stop

#drb_statusObject



256
257
258
259
260
# File 'lib/vedeu/distributed/server.rb', line 256

def_delegators Vedeu::Distributed::Server,
:drb_restart,
:drb_start,
:drb_status,
:drb_stop

#drb_stopObject



256
257
258
259
260
# File 'lib/vedeu/distributed/server.rb', line 256

def_delegators Vedeu::Distributed::Server,
:drb_restart,
:drb_start,
:drb_status,
:drb_stop

#eventsVedeu::Events::Repository

Manipulate the repository of events.

Examples:

Vedeu.events


40
41
# File 'lib/vedeu/events/repository.rb', line 40

def_delegators Vedeu::Events::Repository,
:events

#exitObject



144
145
# File 'lib/vedeu/runtime/application.rb', line 144

def_delegators Vedeu::Runtime::Application,
:exit

#focusObject



266
267
268
269
270
271
272
# File 'lib/vedeu/models/focus.rb', line 266

def_delegators Vedeu::Models::Focus,
:focus,
:focus?,
:focus_by_name,
:focussed?,
:focus_next,
:focus_previous

#focus?Object



266
267
268
269
270
271
272
# File 'lib/vedeu/models/focus.rb', line 266

def_delegators Vedeu::Models::Focus,
:focus,
:focus?,
:focus_by_name,
:focussed?,
:focus_next,
:focus_previous

#focus_by_nameObject



266
267
268
269
270
271
272
# File 'lib/vedeu/models/focus.rb', line 266

def_delegators Vedeu::Models::Focus,
:focus,
:focus?,
:focus_by_name,
:focussed?,
:focus_next,
:focus_previous

#focus_nextObject



266
267
268
269
270
271
272
# File 'lib/vedeu/models/focus.rb', line 266

def_delegators Vedeu::Models::Focus,
:focus,
:focus?,
:focus_by_name,
:focussed?,
:focus_next,
:focus_previous

#focus_previousObject



266
267
268
269
270
271
272
# File 'lib/vedeu/models/focus.rb', line 266

def_delegators Vedeu::Models::Focus,
:focus,
:focus?,
:focus_by_name,
:focussed?,
:focus_next,
:focus_previous

#focussed?Object



266
267
268
269
270
271
272
# File 'lib/vedeu/models/focus.rb', line 266

def_delegators Vedeu::Models::Focus,
:focus,
:focus?,
:focus_by_name,
:focussed?,
:focus_next,
:focus_previous

#foreground_coloursVedeu::Colours::Foregrounds



27
28
# File 'lib/vedeu/colours/foregrounds.rb', line 27

def_delegators Vedeu::Colours::Foregrounds,
:foreground_colours

#geometriesVedeu::Geometries::Repository

Manipulate the repository of geometries.

Examples:

Vedeu.geometries


29
30
# File 'lib/vedeu/geometries/repository.rb', line 29

def_delegators Vedeu::Geometries::Repository,
:geometries

#geometryObject

See Also:

  • Vedeu::Geometries::DSL.geometry


282
283
# File 'lib/vedeu/geometries/dsl/dsl.rb', line 282

def_delegators Vedeu::Geometries::DSL,
:geometry

#gotoObject



176
177
# File 'lib/vedeu/runtime/router.rb', line 176

def_delegators Vedeu::Runtime::Router,
:goto

#groupObject



103
104
# File 'lib/vedeu/groups/dsl.rb', line 103

def_delegators Vedeu::Groups::DSL,
:group

#groupsVedeu::Groups::Repository

Manipulate the repository of groups.

Examples:

Vedeu.groups


34
35
# File 'lib/vedeu/groups/repository.rb', line 34

def_delegators Vedeu::Groups::Repository,
:groups

#heightObject



483
484
485
486
487
488
# File 'lib/vedeu/configuration/configuration.rb', line 483

def_delegators Vedeu::Configuration,
:config,
:configure,
:configuration,
:height,
:width

#hide_cursorObject



272
273
274
275
# File 'lib/vedeu/cursors/cursor.rb', line 272

def_delegators Vedeu::Cursors::Cursor,
:hide_cursor,
:show_cursor,
:toggle_cursor

#hide_groupObject



193
194
195
196
# File 'lib/vedeu/groups/group.rb', line 193

def_delegators Vedeu::Groups::Group,
:hide_group,
:show_group,
:toggle_group

#hide_interfaceObject



186
187
188
189
# File 'lib/vedeu/interfaces/interface.rb', line 186

def_delegators Vedeu::Interfaces::Interface,
:hide_interface,
:show_interface,
:toggle_interface

#indentObject



193
194
195
196
197
198
199
# File 'lib/vedeu/logging/log.rb', line 193

def_delegators Vedeu::Logging::Log,
:indent,
:log,
:log_stdout,
:log_stderr,
:log_timestamp,
:outdent

#interfaceObject



324
325
# File 'lib/vedeu/interfaces/dsl.rb', line 324

def_delegators Vedeu::Interfaces::DSL,
:interface

#interfacesVedeu::Interfaces::Repository

Manipulate the repository of interfaces.

Examples:

Vedeu.interfaces


45
46
# File 'lib/vedeu/interfaces/repository.rb', line 45

def_delegators Vedeu::Interfaces::Repository,
:interfaces

#keymapObject



118
119
# File 'lib/vedeu/input/dsl.rb', line 118

def_delegators Vedeu::Input::DSL,
:keymap

#keymapsVedeu::Input::Repository

Manipulate the repository of keymaps.

Examples:

Vedeu.keymaps


27
28
# File 'lib/vedeu/input/repository.rb', line 27

def_delegators Vedeu::Input::Repository,
:keymaps

#keypressObject



172
173
# File 'lib/vedeu/input/mapper.rb', line 172

def_delegators Vedeu::Input::Mapper,
:keypress

#last_commandObject



84
85
86
87
88
89
90
# File 'lib/vedeu/input/store.rb', line 84

def_delegators Vedeu::Input::Store,
:add_command,
:add_keypress,
:all_commands,
:all_keypresses,
:last_command,
:last_keypress

#last_keypressObject



84
85
86
87
88
89
90
# File 'lib/vedeu/input/store.rb', line 84

def_delegators Vedeu::Input::Store,
:add_command,
:add_keypress,
:all_commands,
:all_keypresses,
:last_command,
:last_keypress

#logObject



193
194
195
196
197
198
199
# File 'lib/vedeu/logging/log.rb', line 193

def_delegators Vedeu::Logging::Log,
:indent,
:log,
:log_stdout,
:log_stderr,
:log_timestamp,
:outdent

#log_stderrObject



193
194
195
196
197
198
199
# File 'lib/vedeu/logging/log.rb', line 193

def_delegators Vedeu::Logging::Log,
:indent,
:log,
:log_stdout,
:log_stderr,
:log_timestamp,
:outdent

#log_stdoutObject



193
194
195
196
197
198
199
# File 'lib/vedeu/logging/log.rb', line 193

def_delegators Vedeu::Logging::Log,
:indent,
:log,
:log_stdout,
:log_stderr,
:log_timestamp,
:outdent

#log_timestampObject



193
194
195
196
197
198
199
# File 'lib/vedeu/logging/log.rb', line 193

def_delegators Vedeu::Logging::Log,
:indent,
:log,
:log_stdout,
:log_stderr,
:log_timestamp,
:outdent


224
225
# File 'lib/vedeu/menus/menu.rb', line 224

def_delegators Vedeu::Menus::DSL,
:menu

Manipulate the repository of menus.

Examples:

Vedeu.menus


28
29
# File 'lib/vedeu/menus/repository.rb', line 28

def_delegators Vedeu::Menus::Repository,
:menus

#outdentObject



193
194
195
196
197
198
199
# File 'lib/vedeu/logging/log.rb', line 193

def_delegators Vedeu::Logging::Log,
:indent,
:log,
:log_stdout,
:log_stderr,
:log_timestamp,
:outdent

#profileVedeu::Logging::Debug



123
124
# File 'lib/vedeu/logging/debug.rb', line 123

def_delegators Vedeu::Logging::Debug,
:profile

#readObject



143
144
# File 'lib/vedeu/input/read.rb', line 143

def_delegators Vedeu::Input::Read,
:read

#ready!Object



78
79
80
# File 'lib/vedeu/runtime/flags.rb', line 78

def_delegators Vedeu::Runtime::Flags,
:ready?,
:ready!

#ready?Object



78
79
80
# File 'lib/vedeu/runtime/flags.rb', line 78

def_delegators Vedeu::Runtime::Flags,
:ready?,
:ready!

#refreshObject



99
100
101
# File 'lib/vedeu/buffers/terminal.rb', line 99

def_delegators Vedeu::Buffers::Terminal,
:clear,
:refresh

#renderObject



169
170
171
172
# File 'lib/vedeu/dsl/views.rb', line 169

def_delegators Vedeu::DSL::Views,
:renders,
:render,
:views

#render_outputObject

See Also:



124
# File 'lib/vedeu/output/output.rb', line 124

def_delegators Vedeu::Output::Output, :render_output

#renderersObject



130
131
# File 'lib/vedeu/renderers/all.rb', line 130

def_delegators Vedeu::Renderers,
:renderers

#rendersObject



169
170
171
172
# File 'lib/vedeu/dsl/views.rb', line 169

def_delegators Vedeu::DSL::Views,
:renders,
:render,
:views

#repositoriesObject

See Also:



75
76
# File 'lib/vedeu/repositories/repositories.rb', line 75

def_delegators Vedeu::Repositories,
:repositories

#requires_gem!(gem_name) ⇒ Boolean

Raises:



35
36
37
38
39
40
41
42
43
44
# File 'lib/vedeu.rb', line 35

def requires_gem!(gem_name)
  require gem_name if Gem::Specification.find_by_name(gem_name)

  true

rescue Gem::LoadError
  raise Vedeu::Error::Fatal,
        "Vedeu requires '#{gem_name}' for this functionality. " \
        "Please add this to your project 'Gemfile' or '*.gemspec'."
end

#resizeObject



173
174
175
176
# File 'lib/vedeu/terminal/terminal.rb', line 173

def_delegators Vedeu::Terminal,
:centre_x,
:centre_y,
:resize

#show_cursorObject



272
273
274
275
# File 'lib/vedeu/cursors/cursor.rb', line 272

def_delegators Vedeu::Cursors::Cursor,
:hide_cursor,
:show_cursor,
:toggle_cursor

#show_groupObject



193
194
195
196
# File 'lib/vedeu/groups/group.rb', line 193

def_delegators Vedeu::Groups::Group,
:hide_group,
:show_group,
:toggle_group

#show_interfaceObject



186
187
188
189
# File 'lib/vedeu/interfaces/interface.rb', line 186

def_delegators Vedeu::Interfaces::Interface,
:hide_interface,
:show_interface,
:toggle_interface

#timerObject



90
91
# File 'lib/vedeu/logging/timer.rb', line 90

def_delegators Vedeu::Logging::Timer,
:timer

#toggle_cursorObject



272
273
274
275
# File 'lib/vedeu/cursors/cursor.rb', line 272

def_delegators Vedeu::Cursors::Cursor,
:hide_cursor,
:show_cursor,
:toggle_cursor

#toggle_groupObject



193
194
195
196
# File 'lib/vedeu/groups/group.rb', line 193

def_delegators Vedeu::Groups::Group,
:hide_group,
:show_group,
:toggle_group

#toggle_interfaceObject



186
187
188
189
# File 'lib/vedeu/interfaces/interface.rb', line 186

def_delegators Vedeu::Interfaces::Interface,
:hide_interface,
:show_interface,
:toggle_interface

#triggerObject



119
120
# File 'lib/vedeu/events/trigger.rb', line 119

def_delegators Vedeu::Events::Trigger,
:trigger

#unbindObject



290
291
292
293
# File 'lib/vedeu/events/event.rb', line 290

def_delegators Vedeu::Events::Event,
:bind,
:bound?,
:unbind

#unbind_aliasObject



94
95
96
# File 'lib/vedeu/events/aliases.rb', line 94

def_delegators Vedeu::Events::Aliases,
:bind_alias,
:unbind_alias

#viewsObject



169
170
171
172
# File 'lib/vedeu/dsl/views.rb', line 169

def_delegators Vedeu::DSL::Views,
:renders,
:render,
:views

#widthObject



483
484
485
486
487
488
# File 'lib/vedeu/configuration/configuration.rb', line 483

def_delegators Vedeu::Configuration,
:config,
:configure,
:configuration,
:height,
:width

#writeObject



118
119
# File 'lib/vedeu/output/write.rb', line 118

def_delegators Vedeu::Output::Write,
:write