Method: Vedeu::Toggleable::SingletonMethods#show
- Defined in:
- lib/vedeu/models/toggleable.rb
#show(name = Vedeu.focus) ⇒ void Also known as: show_group, show_interface
This method returns an undefined value.
Shows the named model, or without a name, the model with same name as the currently focussed interface.
73 74 75 |
# File 'lib/vedeu/models/toggleable.rb', line 73 def show(name = Vedeu.focus) repository.by_name(name).show end |